Allele Visualisation - FDSTools

Input & output

Allele list file:
(or drag a file onto this page)
Save image

Description

The graph depicts every allele among the reference samples as a circle. The size of the circle corresponds to the number of samples with that particular allele. A black inner circle depicts the number of homozygotes.

The circles of two alleles are connected by a line whenever samples exist that have a combination of the two connected alleles. The thickness of the line corresponds to the number of heterozygotes with that particular combination of alleles.

Display options

Graph width | px
Graph height | px
Renderer | SVG | Canvas